PAWpySeed: pawpyseed.analysis.plots Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Variables
pawpyseed.analysis.plots Namespace Reference

## Variables
| f = open('tst.txt', 'r')
| myd = yaml.load(f)
| yh = myd['yh']
| r = myd['r']
| label

## Variable Documentation

pawpyseed.analysis.plots.f = open('tst.txt', 'r')

pawpyseed.analysis.plots.label

pawpyseed.analysis.plots.myd = yaml.load(f)

pawpyseed.analysis.plots.r = myd['r']

pawpyseed.analysis.plots.yh = myd['yh']